@@ -14,7 +14,7 @@
 #' argument equivalent to \eqn{n} in
 #' \ifelse{html}{\out{a<sub>n</sub>}}{\eqn{a_n}} and the second must be a vector
 #' of numeric parameters.
-#' @param parameters A numeric vector with parameters used in logFunction.
+#' @param parameters A numeric vector with parameters used in \code{logFunction}.
 #' Vectorized summation over various parameter values sets is not implemented.
 #' Use \code{\link{apply}} or their variants to achieve this.
 #' @param logL The log of the limit value of
@@ -23,22 +23,21 @@
 #' series is alternating, defined with argument \code{alternate}. If left as
 #' \code{NULL} and \code{logFunction} is defined in \code{R}, the
 #' \code{batches} algorithm with default settings is used. See 'details'.
-#' @param alternate Either -1, 0 or 1. If 0, the series is not alternating.
-#' Otherwise, the series is alternating where the first element's sign is
-#' either 1 or -1, as entered in this parameter. If not 0, arguments \code{logL}
-#' and \code{forceAlgorithm} are ignored.
+#' @param alternate Either -1, 0 or 1. If 0 (or \code{FALSE}), the series is not
+#' alternating and positive. Otherwise, the series is alternating where the
+#' first element's sign is either 1 or -1, as entered in this parameter. If not
+#' 0, arguments \code{logL} and \code{forceAlgorithm} are ignored.
 #' @param epsilon The desired error margin for the approximation. See 'details'.
 #' @param maxIter The maximum number of iterations for the approximation. In
 #' most cases, this number will not be reached unless it is very small. A value
 #' too high is not recommended as an array of this size is reserved in memory
 #' during the algorithm.
-#' @param n0 The sum will be approximated for the series starting at this value.
+#' @param n0 The sum will be approximated for the series starting at this value
+#' for the first parameter of \code{logFunction}.
 #' @param forceAlgorithm A value to control which summation algorithm to use.
 #' Ignored if the series is alternating, defined with argument \code{alternate}.
 #' See 'details'.
-#' @return A list with two named members, \code{sum} and \code{n}. \code{sum} is
-#' the approximated value in the log scale and \code{n} is the total number of
-#' iterations, that is, the number of times the function was evaluated.
+#' @return A \code{\link{summed-objects}} object.
 #' @details The approximated sum is based on some theoretical results which,
 #' analytically, guarantee that the approximation will be within \code{epsilon}
 #' distance to the true value. It is possible that the numerical result fails
@@ -52,9 +51,8 @@
 #' \ifelse{html}{\out{a<sub>n+1</sub>/a<sub>n</sub>}}{\eqn{a_{n+1}/a_n}} must
 #' converge to a number \eqn{L < 1} when \eqn{n} goes to infinity. The log of
 #' \eqn{L} should be provided to the function for a better approximation.
-#' Otherwise, a warning will be given and the program will try to estimate its
-#' value, however, the theoretical result that guarantees the approximation does
-#' not necessarily hold in this case.
+#' This is not necessary in case a precompiled function is used. In this case
+#' the value of \eqn{L} is coded into the package.
 #'
 #' Another requirement in the current installment of this function is that the
 #' series must have only a single maximum. This is the case for most discrete
@@ -84,10 +82,10 @@
 #' pairs becomes almost as fast as the Sum-To-Threshold method.
 #' 
 #' The third algorithm is called batches method and is used when \eqn{L} is
-#' unknown. Its use requires some fine tuning, so there is a standalone function
-#' for it called \code{\link{infiniteSum_batches}}. Its use and functionality
-#' can be seen in its own documentation. When used as a result of this function,
-#' default settings are used.
+#' left at \code{NULL}. Its use requires some fine tuning, so there is a
+#' standalone function for it called \code{\link{infiniteSum_batches}}. Its use
+#' and functionality can be seen in its own documentation. When called as a
+#' result of this function, default settings are used.
 #'
 #' The \code{forceAlgorithm} parameter can be used to
 #' control which algorithm to use. When it is 0, the program automatically
@@ -108,7 +106,7 @@
 #' precompiled function in the package. The list of precompiled functions can
 #' be found in \code{\link{precompiled}}, and more functions will be added in
 #' time. As is intuitive, using a precompiled function is much faster than using
-#' an \code{R} function. In fact, it has been observed to be dozens time faster.
+#' an \code{R} function. In fact, it has been observed to be dozens times faster.
 #'
 #' The advanced user can program their own precompiled functions and use the
 #' package's summation algorithms by linking the appropriate header file. See
@@ -120,12 +118,12 @@
 #' argument.
 #' @examples
 #' ## Define some function that is known to pass the ratio test.
-#' param = 0.1
+#' param <- 0.1
 #' funfun <- function(k, p) return(k * log1p(-p[1]))
 #' result <- infiniteSum(funfun, parameters = param, logL = log1p(-param))
 #'
 #' ## This series is easy to verify analytically
-#' TrueSum = -log(param)
+#' TrueSum <- -log(param)
 #' TrueSum - result$sum
 #' # Since exp(logL) = 0.9, the Error bounding pairs
 #' # algorithm is used. Notice that it only required
@@ -135,19 +133,19 @@
 #' ## A common problem is finding the normalizing constant for the
 #' ## Conway-Maxwell-Poisson distribution. It has already been included
 #' ## in the precompiled list of functions.
-#' comp_params = c(lambda = 5, nu = 3)
+#' comp_params <- c(lambda = 5, nu = 3)
 #' result <- infiniteSum("COMP", comp_params)
 #' result
 #' @export
 infiniteSum <- function(logFunction, parameters = numeric(), logL = NULL,
-                        alternate = 0,  epsilon = 1e-15, maxIter = 1e5, n0 = 0,
-                        forceAlgorithm = 0){
+                        alternate = FALSE,  epsilon = 1e-15, maxIter = 1e5,
+                        n0 = 0, forceAlgorithm = 0){
 
   # Make these tests at the C level to make function faster.
   stopifnot(is.function(logFunction) || is.character(logFunction),
             length(logFunction) == 1,
             is.numeric(parameters),
-            is.numeric(alternate),
+            is.numeric(alternate) || isFALSE(alternate),
             alternate %in% -1:1,
             is.numeric(epsilon),
             epsilon > 0,
